@@ -75,7 +75,7 @@ def neglect(test):
         exit(0)
 
 
-    f5=open("test.py", 'r')
+    f5=open(test, 'r')
     data=f5.readlines()
 
 
@@ -109,7 +109,7 @@ def neglect(test):
 
 
     f5.close()
-    f4=open("test.py", 'w')
+    f4=open(test, 'w')
     f4.writelines(data)
     f4.close()
     f3.close()
